Archive completed changes and update specifications. Archive completed changes.
Archiving moves a change directory into the archive area and can copy spec
deltas back into the main specs/ tree.
This module also includes a small helper for determining whether a
tasks.md file is fully complete.
Enums
- Task
Status - Summary of task completion for a change.
Functions
- archive_
exists - Return
trueif{ito_path}/changes/archive/{archive_name}exists. - categorize_
specs - Split spec ids into those already present in main specs and those that are new.
- change_
exists - Return
trueif the change exists. - check_
task_ completion - Check whether the tasks in
contentsare complete. - copy_
specs_ to_ main - Copy change spec deltas to the main specs tree.
- discover_
change_ specs - Discover spec ids present under
{change}/specs/*/spec.md. - generate_
archive_ name - Generate an archive folder name for
change_name. - list_
available_ changes - List available change directories under
{ito_path}/changes. - move_
to_ archive - Move a change directory to the archive location.