pub fn read_audit_events(ito_path: &Path) -> Vec<AuditEvent>Expand description
Read all audit events from the project’s JSONL file.
Malformed lines are skipped with a tracing warning. If the file does not exist, returns an empty vector.
pub fn read_audit_events(ito_path: &Path) -> Vec<AuditEvent>Read all audit events from the project’s JSONL file.
Malformed lines are skipped with a tracing warning. If the file does not exist, returns an empty vector.