poll_new_events

Function poll_new_events 

pub fn poll_new_events(sources: &mut [StreamSource]) -> Vec<StreamEvent>
Poll all sources for new events since the last check.

Updates the offsets in each source so subsequent polls only return new events.