pub fn validate_audit_log(
ito_path: &Path,
change_id: Option<&str>,
) -> AuditValidationReportExpand description
Run semantic validation on the audit log for a specific change or the whole project.
pub fn validate_audit_log(
ito_path: &Path,
change_id: Option<&str>,
) -> AuditValidationReportRun semantic validation on the audit log for a specific change or the whole project.