Module worktree

Module worktree 

Worktree discovery for audit event aggregation and streaming.

Uses git worktree list --porcelain to enumerate all worktrees and resolves their audit event file paths.

Functions

aggregate_worktree_events
Read and aggregate events from all worktrees.
discover_worktrees
Discover all git worktrees that have an audit events file.
find_worktree_for_branch
Find the worktree path for a branch by parsing git worktree list --porcelain.
worktree_audit_log_path
Get the audit log path for a worktree.