Backend HTTP client for repository reads. HTTP client for backend repository reads and task mutations.
Structs
- Backend
Http Client - Backend HTTP client shared across repository adapters.
Backend HTTP client for repository reads. HTTP client for backend repository reads and task mutations.