Module capabilities

Module capabilities 

Compile-time capability reporting and configuration preflight. Compile-time capability reporting and configuration preflight.

Structs

CompiledCapabilities
A caller-reported set of compiled capabilities.

Enums

CapabilityPreflight
How the caller intends to use the resolved configuration.
CompiledFeature
Experimental implementation that may be absent from a compiled Ito binary.

Functions

preflight_config
Reject configuration that requests an implementation absent from this binary.
preflight_config_with_capabilities
Reject configuration against the capabilities reported by the executable.