pub fn read_json_config(path: &Path) -> CoreResult<Value>Expand description
Read a JSON config file, returning an empty object if the file doesn’t exist.
Errors
Returns CoreError::Serde if the file contains invalid JSON or is not a JSON object.
pub fn read_json_config(path: &Path) -> CoreResult<Value>Read a JSON config file, returning an empty object if the file doesn’t exist.
Returns CoreError::Serde if the file contains invalid JSON or is not a JSON object.