Module distribution

Module distribution 

Distribution/build metadata helpers. Embedded asset distribution helpers.

This module builds install manifests for the various harnesses Ito supports. The manifests map a file embedded in ito-templates to a destination path on disk.

Structs

FileManifest
One file to be installed from embedded assets.

Enums

AssetType
Category of embedded asset.

Functions

claude_manifests
Return manifest entries for Claude Code template installation.
codex_manifests
Return manifest entries for Codex template installation.
github_manifests
Return manifest entries for GitHub Copilot template installation.
install_manifests
Install manifests from embedded assets to disk.
opencode_manifests
Return manifest entries for OpenCode template installation.
pi_manifests
Return manifest entries for Pi coding agent template installation.