pub fn parse_change_id(input: &str) -> Result<ParsedChangeId, IdParseError>Expand description
Parse a change identifier.
Accepts flexible padding for the module and change numbers, but always returns a canonical representation.
pub fn parse_change_id(input: &str) -> Result<ParsedChangeId, IdParseError>Parse a change identifier.
Accepts flexible padding for the module and change numbers, but always returns a canonical representation.