Module git_remote

Module git_remote 

Git remote URL resolution for org/repo namespace discovery. Git remote URL resolution for org/repo namespace discovery.

Provides helpers to determine the (org, repo) pair for the current project by consulting config first and falling back to the origin remote URL when config is incomplete.

Functions

parse_remote_url_org_repo
Parse <org>/<repo> from a git remote URL.
resolve_org_repo_from_config_or_remote
Resolve the (org, repo) pair for the current project.
resolve_org_repo_from_remote
Attempt to resolve (org, repo) from the origin remote URL only.