Module harness

Module harness 

Harness integrations for running AI-assisted workflows. Harness integrations for running AI-assisted workflows.

A harness is an adapter around a specific agent runtime (e.g. OpenCode) that can execute Ito workflows and return structured results.

All CLI-based harnesses implement the CliHarness trait, which provides a blanket Harness impl — so adding a new CLI harness only requires implementing three small methods.

Re-exports

pub use claude_code::ClaudeCodeHarness;
pub use codex::CodexHarness;
pub use github_copilot::GitHubCopilotHarness;
pub use opencode::OpencodeHarness;
pub use types::Harness;
pub use types::HarnessName;
pub use types::HarnessRunConfig;
pub use types::HarnessRunResult;

Modules

claude_code
Claude Code harness implementation.
codex
OpenAI Codex harness implementation.
github_copilot
GitHub Copilot harness implementation.
opencode
OpenCode harness implementation.
streaming_cli
Streaming CLI harness trait and process management.
stub
No-op/stub harness used for testing.
types
Shared harness types.