install_default_templates

Function install_default_templates 

pub fn install_default_templates(
    project_root: &Path,
    ctx: &ConfigContext,
    mode: InstallMode,
    opts: &InitOptions,
    worktree_ctx: Option<&WorktreeTemplateContext>,
) -> CoreResult<()>
Install the default project templates and selected tool adapters.

When worktree_ctx is Some, templates containing Jinja2 syntax will be rendered with the given worktree configuration. When None, a disabled default context is used.