pub fn resolve_worktree_paths(
env: &ResolvedEnv,
ctx: &ConfigContext,
) -> CoreResult<ResolvedWorktreePaths>Expand description
Computes worktree layout paths from the resolved environment and repository-local configuration.
pub fn resolve_worktree_paths(
env: &ResolvedEnv,
ctx: &ConfigContext,
) -> CoreResult<ResolvedWorktreePaths>Computes worktree layout paths from the resolved environment and repository-local configuration.