pub fn load_delta_spec_file(path: &Path) -> CoreResult<DeltaSpecFile>Expand description
Load a delta spec.md and infer the spec id from its parent directory.
pub fn load_delta_spec_file(path: &Path) -> CoreResult<DeltaSpecFile>Load a delta spec.md and infer the spec id from its parent directory.