read_change_schema

Function read_change_schema 

pub fn read_change_schema(ito_path: &Path, change: &str) -> String
Determines the schema name configured for a change by reading its metadata.

Returns the schema name configured for the change, or the default schema name (spec-driven) if none is set.

Examples

use std::path::Path;

let name = read_change_schema(Path::new("/nonexistent/path"), "nope");
assert_eq!(name, "spec-driven");