pub fn validate_spec_markdown(markdown: &str, strict: bool) -> ValidationReportExpand description
Validate a spec markdown string and return a structured report.
pub fn validate_spec_markdown(markdown: &str, strict: bool) -> ValidationReportValidate a spec markdown string and return a structured report.