pub fn with_line(i: ValidationIssue, line: u32) -> ValidationIssueExpand description
Attach a 1-based line number to an existing issue.
Use this when the issue can be pinpointed to a specific line.
pub fn with_line(i: ValidationIssue, line: u32) -> ValidationIssueAttach a 1-based line number to an existing issue.
Use this when the issue can be pinpointed to a specific line.