Module worktree_validate

Module worktree_validate 

Read-only validation of whether the current checkout matches an expected change worktree. Read-only validation of whether the current checkout matches an expected change worktree.

Structs

WorktreeValidation
Machine-readable worktree validation result for humans and hook callers.

Enums

WorktreeValidationStatus
Distinct outcomes for worktree validation.

Functions

validate_change_worktree
Validate that the current checkout is an acceptable worktree for change_id.