pub fn copy_specs_to_main( ito_path: &Path, change_name: &str, spec_names: &[String], ) -> CoreResult<Vec<String>>
Copy change spec deltas to the main specs tree.
Returns the list of spec ids that were written.