Audit log infrastructure: writer, reader, reconciliation, worktree discovery. Audit log infrastructure: filesystem writer, event reader, reconciliation engine, worktree discovery, and stream watcher.
Re-exports
pub use reader::EventFilter;pub use reader::read_audit_events;pub use reader::read_audit_events_filtered;pub use reconcile::ReconcileReport;pub use reconcile::build_file_state;pub use reconcile::run_reconcile;pub use stream::StreamConfig;pub use stream::StreamEvent;pub use stream::poll_new_events;pub use stream::read_initial_events;pub use worktree::aggregate_worktree_events;pub use worktree::discover_worktrees;pub use worktree::find_worktree_for_branch;pub use writer::FsAuditWriter;
Modules
- mirror
- Best-effort synchronization of the local audit log to a dedicated remote branch.
- ops
- Operation type constants for each entity.
- reader
- Audit log reader: parse events from JSONL file with optional filtering.
- reconcile
- Reconciliation engine: compare audit log against file-on-disk state, detect drift, and optionally emit compensating events.
- stream
- Poll-based audit event streaming with multi-worktree support.
- validate
- Semantic validation for audit event logs.
- worktree
- Worktree discovery for audit event aggregation and streaming.
- writer
- Filesystem-backed audit log writer.
Structs
- Audit
Event - A single audit event recording a domain state transition.
- Audit
Event Builder - Builder for constructing
AuditEventinstances. - Event
Context - Session and git context captured at event-write time.
Enums
- Actor
- Known actor types for the audit log.
- Entity
Type - Known entity types for the audit log.
Traits
- Audit
Writer - Trait for appending audit events to a log.
Functions
- resolve_
context - Resolve the full
EventContextfor the current CLI invocation. - resolve_
user_ identity - Resolve the user identity for the
byfield.