pub fn read_initial_events(
ito_path: &Path,
config: &StreamConfig,
) -> (Vec<StreamEvent>, Vec<StreamSource>)Expand description
Read the initial batch of events for streaming (the last N events).
Returns events from the main project log and, if all_worktrees is true,
from all discovered worktrees.