Worktree discovery for audit event aggregation and streaming.
Uses git worktree list --porcelain to enumerate all worktrees and
resolves their audit event file paths.
Functions
- aggregate_
worktree_ events - Read and aggregate events from all worktrees.
- discover_
worktrees - Discover all git worktrees that have an audit events file.
- find_
worktree_ for_ branch - Find the worktree path for a branch by parsing
git worktree list --porcelain. - worktree_
audit_ log_ path - Get the audit log path for a worktree.