pub fn discover_worktrees(_ito_path: &Path) -> Vec<WorktreeInfo>Expand description
Discover all git worktrees that have an audit events file.
Returns an empty vec if git is unavailable, not in a repo, or no worktrees have audit logs.
pub fn discover_worktrees(_ito_path: &Path) -> Vec<WorktreeInfo>Discover all git worktrees that have an audit events file.
Returns an empty vec if git is unavailable, not in a repo, or no worktrees have audit logs.