Local-to-backend import orchestration. Local-to-backend import orchestration.
Structs
- Import
Item Result - Outcome for a single processed import item.
- Import
Summary - Summary returned by the import orchestration.
- Local
Import Change - A local change ready to be imported into backend-managed state.
- Repository
Backed Import Sink - Import sink backed by the existing backend read/sync/archive ports.
Enums
- Import
Action - Sink result for a single import item.
- Import
Item Status - Final status for one imported item.
- Import
Lifecycle - Lifecycle state for a locally discovered change import.
Traits
- Backend
Import Sink - Output port for applying one imported change to backend-managed state.
Functions
- import_
local_ changes - Discover local active and archived changes, then import them through a sink.
- import_
local_ changes_ with_ options - Discover local changes, then import or preview them through a sink.