Git synchronization helpers for coordination workflows. Git synchronization helpers for coordination workflows.
Structs
- Coordination
GitError - Structured failure details for coordination branch operations.
Enums
- Coordination
GitError Kind - Error category for coordination branch git operations.
Functions
- fetch_
coordination_ branch - Fetches a coordination branch from
origininto remote-tracking refs. - fetch_
coordination_ branch_ core - CoreResult wrapper for fetching a coordination branch.
- push_
coordination_ branch - Pushes a local ref to a coordination branch on
origin. - push_
coordination_ branch_ core - CoreResult wrapper for pushing a local ref to a coordination branch.
- reserve_
change_ on_ coordination_ branch - Reserves a newly created change directory on the coordination branch.
- reserve_
change_ on_ coordination_ branch_ core - CoreResult wrapper for reserving change metadata on the coordination branch.