pub fn grep(
ito_path: &Path,
input: &GrepInput,
change_repo: &dyn ChangeRepository,
module_repo: &dyn ModuleRepository,
) -> CoreResult<GrepOutput>Expand description
Resolve the grep scope to a list of artifact files and execute the search.
Arguments
ito_path- Path to the.ito/directory.input- The grep parameters (pattern, scope, limit).change_repo- A change repository for resolving targets and listing changes.module_repo- A module repository for resolving module targets.
Errors
Returns errors if the change/module cannot be found or the pattern is invalid.