pub fn resolve_env(ctx: &ConfigContext) -> CoreResult<ResolvedEnv>Expand description
Resolve repository and Ito-related roots for the current working directory.
This function determines the worktree root, project root, Ito directory, and whether the current repository is bare.