Statistics collection and computation for command usage. Statistics collection and computation for Ito command usage.
This module provides functions to parse execution logs and compute
command usage statistics from .jsonl log files.
Structs
- Command
Stats - Statistics about command usage, keyed by command ID.
Functions
- collect_
jsonl_ files - Recursively collect all
.jsonlfiles in a directory tree. - compute_
command_ stats - Compute command usage statistics from execution logs.
- known_
command_ ids - Return the static list of known Ito command IDs.