pub fn known_command_ids() -> &'static [&'static str]Expand description
Return the static list of known Ito command IDs.
This list is used to initialize the stats map with zero counts for all known commands, even if they haven’t been executed yet.