pub fn export_embedded_schemas(
to_dir: &Path,
force: bool,
) -> Result<ExportSchemasResult, WorkflowError>Expand description
Export all embedded schema files into a target directory.
Existing destination files are not overwritten unless force is true.