BackendArchiveClient

Trait BackendArchiveClient 

pub trait BackendArchiveClient {
    // Required method
    fn mark_archived(
        &self,
        change_id: &str,
    ) -> Result<ArchiveResult, BackendError>;
}
Port for backend archive lifecycle operations.

Marks a change as archived on the backend, making it immutable for subsequent backend operations (no further writes or leases).

Required Methods

fn mark_archived(&self, change_id: &str) -> Result<ArchiveResult, BackendError>

Mark a change as archived on the backend.

After this call succeeds, the backend SHALL reject further write or lease operations for the change.

Implementors