pub fn validate_change_dirs_repo_integrity(
ito_path: &Path,
) -> CoreResult<BTreeMap<String, Vec<ValidationIssue>>>Expand description
Validate change directory naming and cross-references.
The returned map is keyed by change directory name. A directory is present in the map only if at least one integrity issue was found.