pub fn warning(
path: impl AsRef<str>,
message: impl Into<String>,
) -> ValidationIssueExpand description
Creates a WARNING level issue.
Use this for potential problems that should be fixed but do not strictly prevent the operation from succeeding (unless strict mode is enabled).