copy_include_files

Function copy_include_files 

pub fn copy_include_files(
    config: &WorktreeInitConfig,
    source_root: &Path,
    dest_root: &Path,
) -> CoreResult<Vec<PathBuf>>
Copy matched include files from source_root into dest_root, preserving relative paths.

Destination files that already exist are skipped to preserve any edits the user may have made (e.g. during partial-init recovery). Missing source files are also silently skipped.

Returns the list of files that were actually copied.