Read-only validation of whether the current checkout matches an expected change worktree. Read-only validation of whether the current checkout matches an expected change worktree.
Structs
- Worktree
Validation - Machine-readable worktree validation result for humans and hook callers.
Enums
- Worktree
Validation Status - Distinct outcomes for worktree validation.
Functions
- validate_
change_ worktree - Validate that the current checkout is an acceptable worktree for
change_id.